@@ -110,11 +110,17 @@ class AzureSynthesizerConfig(SynthesizerConfig, type=SynthesizerType.AZURE):
         )
 
 
+DEFAULT_GOOGLE_LANGUAGE_CODE = "en-US"
+DEFAULT_GOOGLE_VOICE_NAME = "en-US-Neural2-I"
+DEFAULT_GOOGLE_PITCH = 0
+DEFAULT_GOOGLE_SPEAKING_RATE = 1.2
+
+
 class GoogleSynthesizerConfig(SynthesizerConfig, type=SynthesizerType.GOOGLE):
-    language_code: str = "en-US"
-    voice_name: str = "en-US-Neural2-I"
-    pitch: float = 0
-    speaking_rate: float = 1.2
+    language_code: str = DEFAULT_GOOGLE_LANGUAGE_CODE
+    voice_name: str = DEFAULT_GOOGLE_VOICE_NAME
+    pitch: float = DEFAULT_GOOGLE_PITCH
+    speaking_rate: float = DEFAULT_GOOGLE_SPEAKING_RATE
 
 
 ELEVEN_LABS_ADAM_VOICE_ID = "pNInz6obpgDQGcFmaJgB"
